@@ -8,6 +8,7 @@ from .globals import (
     get_active_span,
     get_fallback,
     set_active_span,
+    debug,
 )
 from .tracer import tracer
 
@@ -22,6 +23,9 @@ def altair_data_transformer(data):
     save the ibis expression globally with that name so we can pick it up later.
     """
     assert isinstance(data, pandas.DataFrame)
+    # If there is no ibis attribute, then reutrn the fallback
+    if not hasattr(data, "ibis"):
+        return altair.default_data_transformer(data)
     expr = data.ibis
 
     if get_fallback():
@@ -30,8 +34,9 @@ def altair_data_transformer(data):
     if not get_active_span():
         set_active_span(tracer.start_span("altair", tags={tags.SERVICE: "kernel"}))
 
-    get_active_span().log_kv({"sql:initial": expr.compile()})
-
+    sql = expr.compile()
+    get_active_span().log_kv({"sql:initial": sql})
+    debug("sql:initial", {"sql": sql})
     h = str(hash(expr))
     name = f"{DATA_NAME_PREFIX}{h}"
     _expr_map[h] = expr
